==> plplot_5.10.0.orig.tar.gz: plplot-5.10.0/doc/doxygen/html/search/defines_64.js <==
var searchData=
[
  ['data_5fdir',['DATA_DIR',['../plplot__config_8h.html#a48cc0a91e8f54c62f3341c21c8cc74e8',1,'plplot_config.h']]],
  ['dbug_5fenter',['dbug_enter',['../tclMatrix_8c.html#a6654afec69a24f13f463c90e1c62def5',1,'dbug_enter():&#160;tclMatrix.c'],['../pldebug_8h.html#a6654afec69a24f13f463c90e1c62def5',1,'dbug_enter():&#160;pldebug.h']]],
  ['dcgettext',['dcgettext',['../plplotcanvas-hacktext_8c.html#a115dd6a6dd9d7a249f6374a7c06deef5',1,'plplotcanvas-hacktext.c']]],
  ['debug',['DEBUG',['../plcore_8c.html#ad72dbcf6d0153db1b8d8a58001feed83',1,'DEBUG():&#160;plcore.c'],['../plctrl_8c.html#ad72dbcf6d0153db1b8d8a58001feed83',1,'DEBUG():&#160;plctrl.c'],['../plmap_8c.html#ad72dbcf6d0153db1b8d8a58001feed83',1,'DEBUG():&#160;plmap.c'],['../ps_8c.html#ad72dbcf6d0153db1b8d8a58001feed83',1,'DEBUG():&#160;ps.c'],['../tk_8c.html#ad72dbcf6d0153db1b8d8a58001feed83',1,'DEBUG():&#160;tk.c'],['../tkwin_8c.html#ad72dbcf6d0153db1b8d8a58001feed83',1,'DEBUG():&#160;tkwin.c'],['../xwin_8c.html#ad72dbcf6d0153db1b8d8a58001feed83',1,'DEBUG():&#160;xwin.c']]],
  ['debugx',['DEBUGx',['../plframe_8c.html#aa0e4d6a92f0c37ad99ae6f1053184ed5',1,'plframe.c']]],
  ['declare_5fplapp',['DECLARE_PLAPP',['../wxwidgets_8h.html#a5eda1e630d912b7d19a2aa0358ae8e78',1,'wxwidgets.h']]],
  ['def_5fplframe_5fbg_5fcolor',['DEF_PLFRAME_BG_COLOR',['../plframe_8c.html#a93009e093b0641f30748d9d2c0e5b859',1,'DEF_PLFRAME_BG_COLOR():&#160;plframe.c'],['../plplotter_8c.html#a93009e093b0641f30748d9d2c0e5b859',1,'DEF_PLFRAME_BG_COLOR():&#160;plplotter.c']]],
  ['def_5fplframe_5fbg_5fmono',['DEF_PLFRAME_BG_MONO',['../plframe_8c.html#ab379accfc1c7b2624804962d6366b4d4',1,'DEF_PLFRAME_BG_MONO():&#160;plframe.c'],['../plplotter_8c.html#ab379accfc1c7b2624804962d6366b4d4',1,'DEF_PLFRAME_BG_MONO():&#160;plplotter.c']]],
  ['def_5fplframe_5fborder_5fwidth',['DEF_PLFRAME_BORDER_WIDTH',['../plframe_8c.html#a84c7f34f97c2af29fd709af39f690a9b',1,'DEF_PLFRAME_BORDER_WIDTH():&#160;plframe.c'],['../plplotter_8c.html#a84c7f34f97c2af29fd709af39f690a9b',1,'DEF_PLFRAME_BORDER_WIDTH():&#160;plplotter.c']]],
  ['def_5fplframe_5fcursor',['DEF_PLFRAME_CURSOR',['../plframe_8c.html#a3c490d20f947eb1cd37fccb0127dfbf2',1,'DEF_PLFRAME_CURSOR():&#160;plframe.c'],['../plplotter_8c.html#a3c490d20f947eb1cd37fccb0127dfbf2',1,'DEF_PLFRAME_CURSOR():&#160;plplotter.c']]],
  ['def_5fplframe_5fheight',['DEF_PLFRAME_HEIGHT',['../plframe_8c.html#a548d59e98ec1be9e47025ae0f024a250',1,'DEF_PLFRAME_HEIGHT():&#160;plframe.c'],['../plplotter_8c.html#a548d59e98ec1be9e47025ae0f024a250',1,'DEF_PLFRAME_HEIGHT():&#160;plplotter.c']]],
  ['def_5fplframe_5frelief',['DEF_PLFRAME_RELIEF',['../plframe_8c.html#a8a65a863211281c46148ca9d5c2283d4',1,'DEF_PLFRAME_RELIEF():&#160;plframe.c'],['../plplotter_8c.html#a8a65a863211281c46148ca9d5c2283d4',1,'DEF_PLFRAME_RELIEF():&#160;plplotter.c']]],
  ['def_5fplframe_5fwidth',['DEF_PLFRAME_WIDTH',['../plframe_8c.html#ad588f83f30259629e69aa7de88e5010f',1,'DEF_PLFRAME_WIDTH():&#160;plframe.c'],['../plplotter_8c.html#ad588f83f30259629e69aa7de88e5010f',1,'DEF_PLFRAME_WIDTH():&#160;plplotter.c']]],
  ['def_5fwidth',['DEF_WIDTH',['../ps_8h.html#a89b0328645e4220f756e2ae014338602',1,'ps.h']]],
  ['default_5fdpi',['DEFAULT_DPI',['../qt_8h.html#a794e0417bdd7ebdad81c59a929932761',1,'qt.h']]],
  ['deg_5fto_5frad',['DEG_TO_RAD',['../plarc_8c.html#a8ed7b6a1f199b6d2af90e642918cf271',1,'plarc.c']]],
  ['device_5fpixels_5fper_5fin',['DEVICE_PIXELS_PER_IN',['../wxwidgets_8h.html#ac27be500dbb52509acecc23bb0eb7c54',1,'DEVICE_PIXELS_PER_IN():&#160;wxwidgets.h'],['../gcw_8h.html#ac27be500dbb52509acecc23bb0eb7c54',1,'DEVICE_PIXELS_PER_IN():&#160;gcw.h']]],
  ['device_5fpixels_5fper_5fmm',['DEVICE_PIXELS_PER_MM',['../wxwidgets_8h.html#a11f2550b698a4ded14be08a8412314e9',1,'DEVICE_PIXELS_PER_MM():&#160;wxwidgets.h'],['../gcw_8h.html#a11f2550b698a4ded14be08a8412314e9',1,'DEVICE_PIXELS_PER_MM():&#160;gcw.h']]],
  ['dgettext',['dgettext',['../plplotcanvas-hacktext_8c.html#ad24abc7110e1bdf384dc2ef2b63e5d07',1,'plplotcanvas-hacktext.c']]],
  ['digmax_5fdef',['DIGMAX_DEF',['../pldtik_8c.html#a2dc186368b713380d9e5fdcc390ee68e',1,'pldtik.c']]],
  ['dirent',['dirent',['../plcore_8c.html#a89957e9be80ef12a50eb4eca72ecd888',1,'plcore.c']]],
  ['dpi',['DPI',['../aqt_8c.html#a9dcb542bc9dbcae41fdb39a689798698',1,'DPI():&#160;aqt.c'],['../cairo_8c.html#a9dcb542bc9dbcae41fdb39a689798698',1,'DPI():&#160;cairo.c']]],
  ['dpmm',['DPMM',['../plplotP_8h.html#abaf07295f4b55cf9e4f5f6b7139505ed',1,'plplotP.h']]],
  ['draw_5flinex',['DRAW_LINEX',['../plplot_8h.html#abc232a5d2bdcfe6d917d28b1d0113261',1,'plplot.h']]],
  ['draw_5flinexy',['DRAW_LINEXY',['../plplot_8h.html#ab0c68fc37f1b7d44b612136a9447a26a',1,'plplot.h']]],
  ['draw_5fliney',['DRAW_LINEY',['../plplot_8h.html#a6b90cdc3b439f3c31a19c9b610732b96',1,'plplot.h']]],
  ['draw_5fsides',['DRAW_SIDES',['../plplot_8h.html#a97f8c99c7977160450c93302222ff923',1,'plplot.h']]],
  ['drv_5fdir',['DRV_DIR',['../plplot__config_8h.html#a1aeab21c6fb43c1aa1c36717a7ad8855',1,'plplot_config.h']]],
  ['drvspec_5flen',['DRVSPEC_LEN',['../test-drv-info_8c.html#afbf160acae1f06ccb188f3c8cdf7f8d1',1,'test-drv-info.c']]],
  ['drvspec_5fsize',['DRVSPEC_SIZE',['../plcore_8c.html#aeccd9f754e3d81d10b32e0449323bafb',1,'plcore.c']]],
  ['dtor',['DTOR',['../plfill_8c.html#a06e28c801ea48dde51889eb3c4836c78',1,'plfill.c']]],
  ['dtr',['dtr',['../plwind_8c.html#a30b567fc9a9ac764ff7bfff0403b469f',1,'plwind.c']]]
];

==> plplot-5.11.1.tar.gz: plplot-5.11.1/doc/doxygen/html/search/defines_64.js <==
var searchData=
[
  ['data_5fdir',['DATA_DIR',['../plplot__config_8h.html#a48cc0a91e8f54c62f3341c21c8cc74e8',1,'plplot_config.h']]],
  ['dbug_5fenter',['dbug_enter',['../tclMatrix_8c.html#a6654afec69a24f13f463c90e1c62def5',1,'dbug_enter():&#160;tclMatrix.c'],['../pldebug_8h.html#a6654afec69a24f13f463c90e1c62def5',1,'dbug_enter():&#160;pldebug.h']]],
  ['debug',['DEBUG',['../plcore_8c.html#ad72dbcf6d0153db1b8d8a58001feed83',1,'DEBUG():&#160;plcore.c'],['../plctrl_8c.html#ad72dbcf6d0153db1b8d8a58001feed83',1,'DEBUG():&#160;plctrl.c'],['../plmap_8c.html#ad72dbcf6d0153db1b8d8a58001feed83',1,'DEBUG():&#160;plmap.c'],['../ps_8c.html#ad72dbcf6d0153db1b8d8a58001feed83',1,'DEBUG():&#160;ps.c'],['../tk_8c.html#ad72dbcf6d0153db1b8d8a58001feed83',1,'DEBUG():&#160;tk.c'],['../tkwin_8c.html#ad72dbcf6d0153db1b8d8a58001feed83',1,'DEBUG():&#160;tkwin.c'],['../wxwidgets__dev_8cpp.html#ad72dbcf6d0153db1b8d8a58001feed83',1,'DEBUG():&#160;wxwidgets_dev.cpp'],['../xwin_8c.html#ad72dbcf6d0153db1b8d8a58001feed83',1,'DEBUG():&#160;xwin.c']]],
  ['debugx',['DEBUGx',['../plframe_8c.html#aa0e4d6a92f0c37ad99ae6f1053184ed5',1,'plframe.c']]],
  ['def_5fplframe_5fbg_5fcolor',['DEF_PLFRAME_BG_COLOR',['../plframe_8c.html#a93009e093b0641f30748d9d2c0e5b859',1,'DEF_PLFRAME_BG_COLOR():&#160;plframe.c'],['../plplotter_8c.html#a93009e093b0641f30748d9d2c0e5b859',1,'DEF_PLFRAME_BG_COLOR():&#160;plplotter.c']]],
  ['def_5fplframe_5fbg_5fmono',['DEF_PLFRAME_BG_MONO',['../plframe_8c.html#ab379accfc1c7b2624804962d6366b4d4',1,'DEF_PLFRAME_BG_MONO():&#160;plframe.c'],['../plplotter_8c.html#ab379accfc1c7b2624804962d6366b4d4',1,'DEF_PLFRAME_BG_MONO():&#160;plplotter.c']]],
  ['def_5fplframe_5fborder_5fwidth',['DEF_PLFRAME_BORDER_WIDTH',['../plframe_8c.html#a84c7f34f97c2af29fd709af39f690a9b',1,'DEF_PLFRAME_BORDER_WIDTH():&#160;plframe.c'],['../plplotter_8c.html#a84c7f34f97c2af29fd709af39f690a9b',1,'DEF_PLFRAME_BORDER_WIDTH():&#160;plplotter.c']]],
  ['def_5fplframe_5fcursor',['DEF_PLFRAME_CURSOR',['../plframe_8c.html#a3c490d20f947eb1cd37fccb0127dfbf2',1,'DEF_PLFRAME_CURSOR():&#160;plframe.c'],['../plplotter_8c.html#a3c490d20f947eb1cd37fccb0127dfbf2',1,'DEF_PLFRAME_CURSOR():&#160;plplotter.c']]],
  ['def_5fplframe_5fheight',['DEF_PLFRAME_HEIGHT',['../plframe_8c.html#a548d59e98ec1be9e47025ae0f024a250',1,'DEF_PLFRAME_HEIGHT():&#160;plframe.c'],['../plplotter_8c.html#a548d59e98ec1be9e47025ae0f024a250',1,'DEF_PLFRAME_HEIGHT():&#160;plplotter.c']]],
  ['def_5fplframe_5frelief',['DEF_PLFRAME_RELIEF',['../plframe_8c.html#a8a65a863211281c46148ca9d5c2283d4',1,'DEF_PLFRAME_RELIEF():&#160;plframe.c'],['../plplotter_8c.html#a8a65a863211281c46148ca9d5c2283d4',1,'DEF_PLFRAME_RELIEF():&#160;plplotter.c']]],
  ['def_5fplframe_5fwidth',['DEF_PLFRAME_WIDTH',['../plframe_8c.html#ad588f83f30259629e69aa7de88e5010f',1,'DEF_PLFRAME_WIDTH():&#160;plframe.c'],['../plplotter_8c.html#ad588f83f30259629e69aa7de88e5010f',1,'DEF_PLFRAME_WIDTH():&#160;plplotter.c']]],
  ['def_5fwidth',['DEF_WIDTH',['../ps_8h.html#a89b0328645e4220f756e2ae014338602',1,'ps.h']]],
  ['default_5fdpi',['DEFAULT_DPI',['../qt_8h.html#a794e0417bdd7ebdad81c59a929932761',1,'qt.h']]],
  ['deg_5fto_5frad',['DEG_TO_RAD',['../plarc_8c.html#a8ed7b6a1f199b6d2af90e642918cf271',1,'plarc.c']]],
  ['digmax_5fdef',['DIGMAX_DEF',['../pldtik_8c.html#a2dc186368b713380d9e5fdcc390ee68e',1,'pldtik.c']]],
  ['dirent',['dirent',['../plcore_8c.html#a89957e9be80ef12a50eb4eca72ecd888',1,'plcore.c']]],
  ['dpi',['DPI',['../aqt_8c.html#a9dcb542bc9dbcae41fdb39a689798698',1,'DPI():&#160;aqt.c'],['../cairo_8c.html#a9dcb542bc9dbcae41fdb39a689798698',1,'DPI():&#160;cairo.c']]],
  ['dpmm',['DPMM',['../plplotP_8h.html#abaf07295f4b55cf9e4f5f6b7139505ed',1,'plplotP.h']]],
  ['draw_5flinex',['DRAW_LINEX',['../plplot_8h.html#abc232a5d2bdcfe6d917d28b1d0113261',1,'plplot.h']]],
  ['draw_5flinexy',['DRAW_LINEXY',['../plplot_8h.html#ab0c68fc37f1b7d44b612136a9447a26a',1,'plplot.h']]],
  ['draw_5fliney',['DRAW_LINEY',['../plplot_8h.html#a6b90cdc3b439f3c31a19c9b610732b96',1,'plplot.h']]],
  ['draw_5fsides',['DRAW_SIDES',['../plplot_8h.html#a97f8c99c7977160450c93302222ff923',1,'plplot.h']]],
  ['driver_5finterface',['DRIVER_INTERFACE',['../metadefs_8h.html#a69063a66eb5cc1673e7898be53e40bd5',1,'metadefs.h']]],
  ['drv_5fdir',['DRV_DIR',['../plplot__config_8h.html#a1aeab21c6fb43c1aa1c36717a7ad8855',1,'plplot_config.h']]],
  ['drvspec_5flen',['DRVSPEC_LEN',['../test-drv-info_8c.html#afbf160acae1f06ccb188f3c8cdf7f8d1',1,'test-drv-info.c']]],
  ['drvspec_5fsize',['DRVSPEC_SIZE',['../plcore_8c.html#aeccd9f754e3d81d10b32e0449323bafb',1,'plcore.c']]],
  ['dtor',['DTOR',['../plfill_8c.html#a06e28c801ea48dde51889eb3c4836c78',1,'plfill.c']]],
  ['dtr',['dtr',['../plwind_8c.html#a30b567fc9a9ac764ff7bfff0403b469f',1,'plwind.c']]]
];
